sqltriples.PgSQLAdapter

Module sqltriples :: Class PgSQLAdapter |
[show private | hide private]
[frames | no frames]

## Class PgSQLAdapter

    Adapter --+
              |
             PgSQLAdapter

Method Summary
| `delete_sequence(self, cursor, sequence_name)`
| `init_sequence(self, cursor, sequence_name)`
Inherited from Adapter
| ``__init__`(self, connection)`
| ``delete_table`(self, cursor, table_name)`
| ``init_table`(self, cursor, table_name)`
| ``query_next_bnode_id`(self, cursor, sequence_name)`

Class Variable Summary
`str` | `paramstyle` = `'pyformat'`

Class Variable Details

    ### paramstyle Type: `str` Value:
        'pyformat'

Generated by Epydoc 2.1 on Fri Mar 31 17:48:37 2006 | http://epydoc.sf.net